package com.ym.mec.student.controller;

import com.ym.mec.auth.api.entity.SysUser;
import com.ym.mec.biz.dal.entity.LuckDrawLog;
import com.ym.mec.biz.dal.page.LuckDrawQueryInfo;
import com.ym.mec.biz.service.LuckDrawCountService;
import com.ym.mec.biz.service.LuckDrawLogService;
import com.ym.mec.biz.service.LuckDrawPrizeService;
import com.ym.mec.biz.service.SysUserService;
import com.ym.mec.common.controller.BaseController;
import com.ym.mec.common.page.PageInfo;
import com.ym.mec.util.string.ValueUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@Api(tags = "抽奖")
@RestController
@RequestMapping(value = "luckDraw")
public class LuckDrawController extends BaseController {

	@Autowired
	private LuckDrawPrizeService luckDrawPrizeService;

	@Autowired
	private LuckDrawLogService luckDrawLogService;

	@Autowired
	private LuckDrawCountService luckDrawCountService;

	@Autowired
	private SysUserService sysUserService;

	@ApiOperation(value = "查询抽奖记录")
	@GetMapping(value = "/list")
	public Object list(LuckDrawQueryInfo queryInfo) {
		SysUser user = sysUserService.getUser();
		if(!queryInfo.getAllFlag()){
			queryInfo.setUserId(user.getId());
		}
		if(queryInfo.getGroupId().equals(3) && user.getOrganId().equals(4)){
			queryInfo.setGroupId(4);
		}
		PageInfo<LuckDrawLog> pageInfo = luckDrawLogService.queryPage(queryInfo);
		for (LuckDrawLog log : pageInfo.getRows()) {
			log.getUser().setPhone(ValueUtil.fuzzyMobile(log.getUser().getPhone()));
		}
		return succeed(pageInfo);
	}

	@ApiOperation(value = "查询我的抽奖记录")
	@GetMapping(value = "/myList")
	public Object myList(LuckDrawQueryInfo queryInfo) {
		SysUser user = sysUserService.getUser();
		if(queryInfo.getGroupId().equals(3) && user.getOrganId().equals(4)){
			queryInfo.setGroupId(4);
		}
		queryInfo.setUserId(user.getId());
		return succeed(luckDrawLogService.queryPage(queryInfo));
	}

	@ApiOperation(value = "抽奖")
	@PostMapping(value = "/draw")
	public Object draw(Integer groupId) {
		SysUser user = sysUserService.getUser();
		if(groupId.equals(3) && user.getOrganId().equals(4)){
			groupId = 4;
		}
		return succeed(luckDrawPrizeService.draw((long) user.getId(), groupId));
	}

	@ApiOperation(value = "查询个人抽奖机会")
	@GetMapping(value = "/queryCount")
	public Object queryCount(Integer groupId) {
		SysUser user = sysUserService.getUser();
		if(groupId.equals(3) && user.getOrganId().equals(4)){
			groupId = 4;
		}
		return succeed(luckDrawCountService.findByIdAndGroupId(user.getId(),groupId));
	}

}
